<?php

namespace Laravel\Appointmant\Policies;

use Litepie\User\Contracts\UserPolicy;
use Laravel\Appointmant\Models\Appointments;

class AppointmentsPolicy
{

    /**
     * Determine if the given user can view the appointments.
     *
     * @param UserPolicy $user
     * @param Appointments $appointments
     *
     * @return bool
     */
    public function view(UserPolicy $user, Appointments $appointments)
    {
        if ($user->canDo('appointmant.appointments.view') && $user->isAdmin()) {
            return true;
        }

        return $appointments->user_id == user_id() && $appointments->user_type == user_type();
    }

    /**
     * Determine if the given user can create a appointments.
     *
     * @param UserPolicy $user
     * @param Appointments $appointments
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('appointmant.appointments.create');
    }

    /**
     * Determine if the given user can update the given appointments.
     *
     * @param UserPolicy $user
     * @param Appointments $appointments
     *
     * @return bool
     */
    public function update(UserPolicy $user, Appointments $appointments)
    {
        if ($user->canDo('appointmant.appointments.edit') && $user->isAdmin()) {
            return true;
        }

        return $appointments->user_id == user_id() && $appointments->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given appointments.
     *
     * @param UserPolicy $user
     * @param Appointments $appointments
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Appointments $appointments)
    {
        return $appointments->user_id == user_id() && $appointments->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given appointments.
     *
     * @param UserPolicy $user
     * @param Appointments $appointments
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Appointments $appointments)
    {
        if ($user->canDo('appointmant.appointments.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given appointments.
     *
     * @param UserPolicy $user
     * @param Appointments $appointments
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Appointments $appointments)
    {
        if ($user->canDo('appointmant.appointments.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
